<?php

namespace Javo\Custom;

use Javo\Api\Settings;

/**
 * Admin
 * use it to write your admin related methods by tapping the settings api class.
 */
class Admin
{
	const PAGE_SETTINGS_KEY = 'jvbpd_page_setting';
	/**
	 * Store a new instance of the Settings API Class
	 * @var class instance
	 */
	public $settings;

	/**
	 * Callback class
	 * @var class instance
	 */
	public $callback;
	public $cache_categories;
	public static $instance;

	/**
	 * Constructor
	 */
	public function __construct()
	{
		$this->settings = new Settings();
	}

	/**
	 * register default hooks and actions for WordPress
	 * @return
	 */
	public function register()
	{
		$this->settings->register();
		$this->enqueue();
		$this->load_admin_helper();
		$this->load_admin_wizard();

		self::$instance = $this;
		add_action('admin_init', array($this, 'tsettings_register'));
		add_action('wp_ajax_jvbpd_theme_settings_save', array($this, 'tsettings_save'));
		add_action('wp_ajax_jvbpd_theme_settings_restore', array($this, 'tsettings_restore'));

		add_filter('wp_setup_nav_menu_item', array($this, 'apparence_menu_define_vars'));
		add_action('wp_update_nav_menu_item', array($this, 'apparence_menu_save_vars'), 10, 3);
		add_filter('wp_edit_nav_menu_walker', array($this, 'apparence_menu_walker'), 10, 2);
		add_action('wp_nav_menu_item_custom_fields', array($this, 'apparence_menu_append_option'), 10, 5);
	}

	/**
	 * Enqueue scripts in specific admin pages
	 * @return $this
	 */
	private function enqueue()
	{
		// Scripts multidimensional array with styles and scripts
		$scripts = array(
			'script' => array(
				'jquery',
				'media_uplaoder',
				get_template_directory_uri() . '/assets/dist/js/admin.js',
			),
			'style' => array(
				get_template_directory_uri() . '/assets/dist/css/admin.css',
				'wp-color-picker'
			)
		);

		// Pages array to where enqueue scripts
		$pages = array();

		// Enqueue files in Admin area
		$this->settings->admin_enqueue($scripts);

		return $this;
	}

	public function load_template($args = array(), $param = array())
	{
		$options = shortcode_atts(
			array(
				'once' => true,
				'ext' => '.php',
				'path' => get_template_directory() . '/views/',
				'sub' => false,
				'name' => '',
			),
			$args
		);

		if (is_array($param)) {
			extract($param);
		}

		$filePath = array();
		$filePath[] = $options['path'];

		if (!empty($options['sub'])) {
			$filePath[] = $options['sub'];
		}

		$filePath[] = $options['name'];
		$fileName = sprintf('%1$s%2$s', join('/', $filePath), $options['ext']);

		if (file_exists($fileName)) {
			if ($options['once']) {
				require_once($fileName);
			} else {
				require($fileName);
			}
		}
	}

	private function load_admin_helper()
	{
		$helperPath = get_template_directory() . '/inc/Custom/admin-helper.php';
		if (file_exists($helperPath)) {
			require_once($helperPath);
		}
	}

	private function load_admin_wizard()
	{
		add_filter('woocommerce_prevent_automatic_wizard_redirect', '__return_true');
		$helperPath = get_template_directory() . '/inc/Custom/init.php';
		if (file_exists($helperPath)) {
			require_once($helperPath);
		}
		if (false) {
			jvbpd_remove_theme_options();
		} else {
			jvbpd_start_wizard();
		}
	}

	private function order_pages($pages, $_pages)
	{
		return $pages['priority'] - $_pages['priority'];
	}

	private function getPages()
	{
		$pages = apply_filters(
			'jvbpd_theme_setting_pages',
			array(
				'general' => array(esc_html__("General", 'javo-directory'), false, 'priority' => 1),
				'header' => array(esc_html__("Header", 'javo-directory'), false, 'priority' => 30),
				'footer' => array(esc_html__("Footer", 'javo-directory'), false, 'priority' => 31),
				'login' => array(esc_html__("Login", 'javo-directory'), false, 'priority' => 41),
				'custom' => array(esc_html__("Custom CSS,JS", 'javo-directory'), false, 'priority' => 70),
				'useful-links' => array(esc_html__("Useful Links", 'javo-directory'), false, 'priority' => 71),
				'import' => array(esc_html__("Import, Export", 'javo-directory'), false, 'priority' => 80),
			)
		);
		uasort($pages, array($this, 'order_pages'));
		return $pages;
	}

	public function tsettings_register()
	{
		register_setting('jvbpd_settings', 'jvbpd_themes_settings');
	}

	public static function getSettingsSaveDates()
	{
		$saveDates = get_option('jvbpd_ts_update_history');
		$saveDates = is_array($saveDates) ? $saveDates : array();
		sort($saveDates, SORT_NUMERIC);
		return array_slice(array_reverse($saveDates), 0, 20);
	}

	public static function updateSettingsSaveDates($options = array())
	{
		$now = time();
		$dates = self::getSettingsSaveDates();
		$dates = array_merge(array($now), $dates);
		update_option('jvbpd_ts_update_history', $dates);
		foreach ($options as $key => $data) {
			update_option($key, $data);
			update_option($key . '_' . $now, $data);
		}
	}

	public function tsettings_save()
	{
		check_ajax_referer('jvbpd_theme_settings_save', '_nonce');

		$arrOptions = isset($_POST['jvbpd_ts']) ? array_map('stripslashes_deep', $_POST['jvbpd_ts']) : array();
		$arrAdsSettings = isset($_POST['jvbpd_ads_settings']) ? $_POST['jvbpd_ads_settings'] : array();

		self::updateSettingsSaveDates(array(
			'jvbpd_themes_settings' => $arrOptions,
			'jvbpd_ads_settings' => json_decode(stripslashes($_POST['jvbpd_ads_settings'])),
		));
		wp_send_json(array('state' => 'OK', 'code' => maybe_serialize($arrOptions)));
	}

	public function tsettings_restore()
	{
		$stamp = isset($_POST['key']) ? $_POST['key'] : null;
		if (!empty($stamp)) {
			foreach (array('jvbpd_themes_settings', 'jvbpd_ads_settings') as $key) {
				$preValue = array_map('stripslashes_deep', get_option($key . '_' .  $stamp));
				update_option($key, $preValue);
			}
		}
		wp_send_json(array('state' => 'OK'));
	}

	public function enqueue_script()
	{
		wp_enqueue_style('javo-settings-style', get_template_directory_uri() . '/assets/dist/css/admin.css');
		wp_register_script('javo-settings', get_template_directory_uri() . '/assets/dist/js/backend.js', array('jquery'));
		wp_localize_script('javo-settings', 'jvbpd_ts_variable', array(
			'ajaxurl' => esc_url(admin_url('admin-ajax.php')),
			'strReset' => esc_html__("Warning : All option results remove and Style initialize.\nContinue?", 'javo-directory'),
			'strImport' => esc_html__("Warning : Change option. can`t option restore. \nContinue?", 'javo-directory'),
		));
		wp_add_inline_script('javo-settings', 'jQuery(function($){ $(document).trigger( "javo:theme_settings_after" ); });');
		wp_enqueue_script('javo-settings');
	}

	public function settings_page_initialize()
	{
		/* Need script and style load */
		wp_enqueue_media();
		add_action('admin_footer', array($this,  'enqueue_script'));

		$current = explode("-", $_GET['page']);
		$pages = $this->getPages();

		if (!defined('ELEMENTOR_VERSION')) {
			unset($pages['footer']);
		}

		// Variable initialize
		$content = "";
		$add_tabs = "";
		$configTabIndex = 0;

		$defaultTab = array_keys($pages)[0]; // Active the first priority tab

		// Repeat create tab menus items
		foreach ($pages as $page => $value) {
			$active = ($page == $defaultTab) ? " nav-tab-active" : "";
			$add_tabs .= sprintf(
				'<li class="nav-item"><a href="#%1$s" class="nav-link d-block text-capitalize %4$s" id="v-pills-%1$s-tab" data-bs-toggle="pill" data-bs-target="#v-pills-%1$s" role="button" aria-controls="v-pills-%1$s" aria-selected="true">%3$s</a></li>',
				$page,
				$value[1],
				ucfirst($value[0]),
				$active,
			);
		}

		$objThsFile	= pathinfo(__FILE__);
		do_action('jvbpd_admin_helper_page_header');
		do_action('jvbpd_admin_helper_' . $objThsFile['filename'] . ' _header'); ?>
		<!-- Theme settings options form -->

		<form id="jvbpd_ts_form" name="jvbpd_theme_settings_form" class="p-0" onsubmit="return false">
			<div class="d-flex justify-content-between p-4 border-bottom border-jv">
				<div class="logo">
					<img class="jv-logo-light" src="<?php echo esc_url(get_template_directory_uri() . '/assets/dist/images/jv-logo-light.png'); ?>">
					<img class="jv-logo-dark" src="<?php echo esc_url(get_template_directory_uri() . '/assets/dist/images/jv-logo-dark.png'); ?>">
					<?php
					/* Get Javo Theme Information */
					$theme_data = wp_get_theme();
					echo "<span class='javo-version-info ps-2'><span>By&nbsp;&nbsp;" . $theme_data['Author'] . "</Author></span>";
					echo "<span>&nbsp;&nbsp;V&nbsp;" . $theme_data['Version'] . "</Author></span></span>";
					?>
				</div>

				<div class="save_area">
					<a href="<?php echo esc_url(apply_filters('jvbpd_doc_url', '')); ?>" target="_blank" class="btn btn-secondary">
						<?php esc_html_e('Documentation', 'javo-directory'); ?>
					</a>
					<input value="Save Settings" class="btn btn-primary jvbpd_btn_ts_save" type="button" id="liveToastBtn">
				</div>
			</div>


			<div class="d-flex ts-menu align-items-start">
				<ul class="nav flex-column nav-pills p-4 pe-0 me-5" id="v-pills-tab" role="tablist" aria-orientation="vertical">
					<?php printf($add_tabs); ?>
				</ul>


				<div class="tab-content w-100 pt-4 ps-5 pe-5 border-start border-jv" id="v-pills-tabContent">
					<?php
					// Tabs contents includes

					if (!empty($pages)) : foreach ($pages as $index => $page) {
							$templatePathArgs = array(get_template_directory(), 'views', 'admin', $index);
							$templatePath = join('/', $templatePathArgs) . '.php';
							if (isset($page['external'])) {
								$templatePath = $page['external'];
							}
							if (file_exists($templatePath)) {
								require_once($templatePath);
							}
						}
					endif; ?>
				</div>
			</div>
			<div class="javo-opts-footer">
				<input name="jvbpd_themes_update" value="<?php echo esc_attr(md5(date("y-m-d"))); ?>" type="hidden">
			</div>

			<div class="toast-container position-fixed top-5 end-0 p-3 z-index-1000">
				<div class="toast jvbpd-ts-status-msg" role="alert" aria-live="assertive" aria-atomic="true">
					<div class="toast-header">
						<div class="spinner-border text-danger spinner-border-sm me-2" role="status">
							<span class="visually-hidden">Loading...</span>
						</div>
						<div class="spinner-grow text-primary spinner-grow-sm me-2" role="status">
							<span class="visually-hidden">Loading...</span>
						</div>
						<strong class="me-auto"><?php esc_html_e("Theme settings", 'javo-directory'); ?></strong>
						<a class="jv-close bg-none" data-bs-dismiss="toast" aria-label="Close"></a>
					</div>
					<div class="toast-body"></div>
				</div>
			</div>
			<input type="hidden" name="action" value="jvbpd_theme_settings_save">
			<input type="hidden" name="_nonce" value="<?php echo wp_create_nonce('jvbpd_theme_settings_save'); ?>">
		</form>

		<!-- Reset & Import Form -->
		<form method="post" action="options.php" id="javo-ts-admin-form">
			<?php settings_fields('jvbpd_settings'); ?>
			<input type="hidden" name="jvbpd_themes_settings" id="javo-ts-admin-field">
		</form>

		<!-- Item Refresh Form -->
		<form id="jvbpd_tso_map_item_refresh" method="post">
			<input type="hidden" name="lang">
			<input type="hidden" name="jvbpd_items_refresh_" value="refresh">
		</form>

		<!-- Item Unserialize Form -->
		<form id="jvbpd_tso_map_item_unserial" method="post">
			<input type="hidden" name="lang">
			<input type="hidden" name="jvbpd_items_unserial_" value="unserial">
		</form>

<?php
		do_action('jvbpd_admin_helper_' . $objThsFile['filename'] . ' _footer');
		do_action('jvbpd_admin_helper_page_footer');
	}

	public function apparence_menu_define_vars($_mnu_item)
	{
		if (!isset($_mnu_item->ID)) {
			return $_mnu_item;
		}
		$_mnu_item->anchor = get_post_meta($_mnu_item->ID, '_menu_item_anchor', true);
		$_mnu_item->scrollspy = get_post_meta($_mnu_item->ID, '_menu_item_scrollspy', true);
		$_mnu_item->nav_icon = get_post_meta($_mnu_item->ID, '_menu_item_icon', true);
		$_mnu_item->css_class = get_post_meta($_mnu_item->ID, '_menu_css_class', true);
		$_mnu_item->wide_menu = get_post_meta($_mnu_item->ID, '_wide_menu', true);
		$_mnu_item->nav_bg = get_post_meta($_mnu_item->ID, '_nav_bg', true);
		$wideMenuCategories = get_post_meta($_mnu_item->ID, '_wide_menu_category', true);
		$wideMenuCategories = is_array($wideMenuCategories) ? $wideMenuCategories : array($wideMenuCategories);
		$_mnu_item->wide_menu_category = array_filter($wideMenuCategories);
		$_mnu_item->wide_menu_listing_category = get_post_meta($_mnu_item->ID, '_wide_menu_listing_category', true);
		$_mnu_item->wide_menu_product_category = get_post_meta($_mnu_item->ID, '_wide_menu_product_category', true);
		$_mnu_item->wide_menu_post_type = get_post_meta($_mnu_item->ID, '_wide_menu_post_type', true);
		$_mnu_item->wide_menu_module = get_post_meta($_mnu_item->ID, '_wide_menu_module', true);
		return $_mnu_item;
	}

	public function apparence_menu_save_vars($_mnu_ID, $_mnu_item_ID, $args)
	{
		if (!is_admin()) {
			return;
		}
		$arrOptions = array(
			'_menu_item_icon',
			'_menu_css_class',
			'_wide_menu',
			'_wide_menu_module',
			'_wide_menu_post_type',
			'_wide_menu_category',
			'_wide_menu_product_category',
			'_wide_menu_listing_category'
		);
		foreach ($arrOptions as $optionName) {
			$strValue = isset($_POST[$optionName][$_mnu_item_ID]) ? $_POST[$optionName][$_mnu_item_ID] : false;
			update_post_meta($_mnu_item_ID, $optionName, $strValue);
		}
	}

	public function apparence_menu_walker()
	{
		$walkerPath = get_template_directory() . '/inc/Api/Callbacks/admin-custom-walker-callback.php';
		if (file_exists($walkerPath)) {
			require_once($walkerPath);
		}
		return 'Walker_Nav_Menu_Edit_Custom';
	}

	public function apparence_menu_append_option($item_id = 0, $menu_item = null, $depth = 0, $args = array(), $current_object_id = 0)
	{
		$this->load_template(array('name' => 'edit-menu', 'sub' => 'admin', 'once' => false), array('jvbpdAdmin' => self::$instance, 'item' => $menu_item, 'item_id' => $item_id));
	}

	public function getNavField($item_id = 0, $item_field_key = '')
	{
		return sprintf('%s[%s]', $item_field_key, $item_id);
	}
}
