<?php

namespace Javo\Setup;

/**
 * Enqueue.
 */
class Enqueue
{
	/**
	 * register default hooks and actions for WordPress
	 * @return
	 */
	public function register()
	{
		add_action( 'wp_enqueue_scripts', Array( $this, 'common_register' ) );
		add_action( 'admin_enqueue_scripts', Array( $this, 'common_register' ) );
		add_action( 'wp_enqueue_scripts', Array( $this, 'enqueue_scripts' ) );
		add_action( 'wp_enqueue_scripts', Array( $this, 'denqueue_scripts' ), 99 );
		add_action( 'wp_enqueue_scripts', Array( $this, 'enqueue_google_font' ) );
		add_action( 'admin_enqueue_scripts', Array( $this, 'admin_enqueue_scripts' ) );
	}

	/**
	 * Notice the mix() function in wp_enqueue_...
	 * It provides the path to a versioned asset by Laravel Mix using querystring-based
	 * cache-busting (This means, the file name won't change, but the md5. Look here for
	 * more information: https://github.com/JeffreyWay/laravel-mix/issues/920 )
	 */
	public function common_register() {
		wp_register_style( 'font-awsome-5', get_template_directory_uri() . '/assets/dist/css/font-awsome.css', array(), '5.15.4', 'all' );
		wp_register_style( 'bootstrap', get_template_directory_uri() . '/assets/dist/css/bootstrap.css', array(), '5.2.1', 'all' );
		wp_register_script( 'jvbpd-app', jvbpd_get_mix_path('js/app.js'), array(), '1.0.0', true );
		//wp_register_style( 'bootstrap-select', 'https://cdn.jsdelivr.net/npm/bootstrap-select@1.14.0-beta3/dist/css/bootstrap-select.min.css', array(), '1.14.0', 'all' );
		//wp_register_style('bootstrap-select', '//cdn.jsdelivr.net/npm/bootstrap-select@1.14.0-beta3/dist/css/bootstrap-select.min.css');

		//wp_register_script( 'bootstrap-select-js', 'https://cdn.jsdelivr.net/npm/bootstrap-select@1.14.0-beta3/dist/js/bootstrap-select.min.js', array(), '1.14.0', 'all' );

	}

	public function enqueue_scripts()
	{
		// CSS
		wp_enqueue_style('font-awsome-5');
		wp_enqueue_style('bootstrap');

		wp_enqueue_style( 'jvbpd-theme', get_template_directory_uri() . '/assets/dist/css/style.css', array(), '1.0.0', 'all' );

		// JS
		wp_enqueue_script( 'jvbpd-app' );
		wp_enqueue_script( 'popper', get_template_directory_uri() . '/assets/dist/js/popper.min.js', array('jquery') );


		// Activate browser-sync on development environment
		if ( getenv( 'APP_ENV' ) === 'development' ) :
			wp_enqueue_script( '__bs_script__', getenv('WP_SITEURL') . ':3000/browser-sync/browser-sync-client.js', array(), null, true );
		endif;

		// Extra
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}
	}

	public function denqueue_scripts() {
		if('enable' == jvbpd_tso()->get('dequeue_google_map', 'disable')) {
			wp_dequeue_script('google-maps');
		}
	}

	public function enqueue_google_font() {
		$strFontParams = '';
		foreach(Array('Open+Sans', 'Poppins', 'Jost') as $fontName) {
			$strFontParams .= sprintf('family=%1$s:wght@300;400;500;600;700;800;900' . '&', $fontName);
		}
		$strLoadFonts = '//fonts.googleapis.com/css2?' . $strFontParams . 'display=swap';
		$strLoadFonts = esc_url_raw( $strLoadFonts );
		wp_enqueue_style( 'jvbpd-google-fonts', $strLoadFonts, Array(), null );
	}

	public function enqueue_google_icon() {
		// Disable enqueue
		$strLoadFonts = add_query_arg(
			Array(
				'family' => 'Material Icons' .'%7c'.
				'Material Icons Outlined' .'%7c'.
				'Material Icons Round' .'%7c'.
				'Material Icons Sharp' .'%7c'.
				'Material Icons Two Tone' .'%7c',
			), '//fonts.googleapis.com/icon'
		);
		$strLoadFonts = esc_url_raw( $strLoadFonts );
		wp_enqueue_style( 'jvbpd-google-icons', $strLoadFonts, Array(), null );
	}

	public function admin_enqueue_scripts() {
		wp_enqueue_script('ace');
		wp_enqueue_script('ace-language-tools');
		wp_enqueue_script('jvbpd-admin', get_template_directory_uri() . '/assets/dist/js/admin.js', array('jquery'), '1.0.0', true);
	}
}
