<div class="card-header pb-3 mb-3 d-flex align-items-baseline gap-2">
    <h3 class="text-primary fs-6"><?php esc_html_e( 'Server status', 'javo-directory'); ?></h3>
	<span class="fw-light opacity-50"><?php esc_html_e( 'Check if your server is ready to use our theme and import data.', 'javo-directory'); ?></span>
</div>

<div class="card-body pt-3 pb-5 text-center">
<?php
$boolAllPassed = null;
$arrCheckLists = Array(
	'php_ver' => Array(
		'label' => esc_html__( "PHP Version", 'javo-directory'),
		'class' => "chk-animation show_one",
		'desc' => esc_html__( "7.3.x", 'javo-directory'),
		'value' => phpversion(),
		'state' => version_compare( '7.3.0', phpversion(), '<=' ),
	),
	'post_max' => Array(
		'label' => esc_html__( "Post Max Size", 'javo-directory'),
		'class' => "chk-animation show_two",
		'desc' => esc_html__( "128M", 'javo-directory'),
		'value' => ini_get( 'post_max_size' ),
		'state' =>
			intVal( apply_filters( 'jvbpd_memory_unit_conversion', '128M' ) ) <=
			intVal( apply_filters( 'jvbpd_memory_unit_conversion', ini_get( 'post_max_size' ) ) ),
	),
	'limit_memory' => Array(
		'label' => esc_html__( "WP MEMORY LIMIT", 'javo-directory'),
		'class' => "chk-animation show_three",
		'desc' => esc_html__( "128M", 'javo-directory'),
		'value' => WP_MEMORY_LIMIT,
		'state' =>
			intVal( apply_filters( 'jvbpd_memory_unit_conversion', '128M' ) ) <=
			intVal( apply_filters( 'jvbpd_memory_unit_conversion', WP_MEMORY_LIMIT ) ),
	),
	'limit_wp_memory' => Array(
		'label' => esc_html__( "MEMORY LIMIT", 'javo-directory'),
		'class' => "chk-animation show_four",
		'desc' => esc_html__( "128M", 'javo-directory'),
		'value' => ini_get('memory_limit'),
		'state' =>
			-1 || // (-1 == Unlimited)
			intVal( apply_filters( 'jvbpd_memory_unit_conversion', '128M' ) ) <=
			intVal( apply_filters( 'jvbpd_memory_unit_conversion', ini_get('memory_limit') ) ),
	),
	'wp_debug' => Array(
		'label' => esc_html__( "WP DEBUG", 'javo-directory'),
		'class' => "chk-animation show_five",
		'desc' => esc_html__( "Off", 'javo-directory'),
		'value' => ( WP_DEBUG ? esc_html__( "On", 'javo-directory') : esc_html__( "Off", 'javo-directory') ),
		'state' => defined( 'WP_DEBUG' ) && ! WP_DEBUG,
	),
); ?>

<table class="table">
	<thead>
		<tr>
			<th></th>
			<th class="text-center"><?php esc_html_e( "Recommended", 'javo-directory'); ?></th>
			<th class="text-center"><?php esc_html_e( "Your Server", 'javo-directory'); ?></th>
			<th class="text-center"><?php esc_html_e( "Status", 'javo-directory'); ?></th>
		</tr>
	</thead>
	<tbody>
		<?php
		if( !empty( $arrCheckLists ) ) {
			foreach( $arrCheckLists as $strKey => $arrMeta ) {
				$boolAllPassed = $boolAllPassed === null ? $arrMeta['state'] : $boolAllPassed && $arrMeta['state'];
				?>
				<tr class="chk-result <?php echo esc_attr( $arrMeta[ 'state' ] ? 'passed' : 'failed' ); ?>">
					<th class="text-left  <?php echo esc_attr( $arrMeta[ 'state' ] ? 'opacity-75' : 'opacity-100' ); ?>"><?php echo esc_html( $arrMeta[ 'label' ] ); ?></th>
					<td class="text-center opacity-75"><span><?php echo esc_html( $arrMeta[ 'desc' ] ); ?></span></td>
					<td class="text-center"><span class="<?php echo esc_html( $arrMeta[ 'class' ] ); ?> <?php echo esc_attr( $arrMeta[ 'state' ] ? 'text-primary' : 'text-danger' ); ?>"><?php echo esc_html($arrMeta[ 'value' ] ); ?></span></td>
					<td class="text-center"><span class="dashicons <?php echo esc_html( $arrMeta[ 'class' ] ); ?> <?php echo esc_attr( $arrMeta[ 'state' ] ? 'dashicons-yes text-primary' : 'dashicons-no text-danger' ); ?>"></span></td>
				</tr>
				<?php
			}
		} ?>
	</tbody>
</table>

<?php if(!$boolAllPassed) { ?>
	<div class="chk-warning pt-3 chk-animation show_btn <?php echo esc_attr( $boolAllPassed ? 'passed text-primary' : 'failed blinking text-warning opacity-50' ); ?>">
		<span class="spinner-grow spinner-grow-sm" role="status"></span>
		<span class="fs-6 fw-bold text-uppercase"><?php esc_html_e("Warning", 'javo-directory'); ?></span>
		<div class="mt-2" ><?php esc_html_e("Problem found. Please check status and contact your server support to fix the issue.", 'javo-directory'); ?></div>
	</div>
<?php } ?>
</div>

<div class="card-footer d-flex justify-content-between align-items-center pt-3 pb-3 <?php echo esc_attr( $boolAllPassed ? 'passed' : 'failed' ); ?>">
	<div class="d-flex gap-2" role="group" aria-label="Basic outlined example">
        <a href="https://www.youtube.com/watch?v=nrLzsw0eDrw" target="_blank" class="btn btn-danger"><i class="fa fa-youtube me-2"></i><?php esc_html_e( 'Video Tutorial', 'javo-directory'); ?></a>
        <a href="https://docs.wpjavo.com/theme/how-to-import-demo-data-steps/" target="_blank" class="btn btn-outline-primary"><?php esc_html_e( 'Install Documentation', 'javo-directory'); ?></a>
    </div>
    <div class="d-flex align-items-center justify-content-end position-relative">
		<div class="hideMe position-absolute right-0 top-25">
			<span class="spinner-border text-primary spinner-border-sm" role="status"></span>
		</div>
		<?php if(!$boolAllPassed) { ?>
			<button type="button" class="btn btn-secondary chk-animation show_btn"  data-bs-toggle="modal" data-bs-target="#exampleModal">
				<?php esc_html_e( 'Ignore & Next', 'javo-directory'); ?>
			</button>
			<?php }else{ ?>
			<a href="<?php echo esc_url( $helper->get_next_step_link() ); ?>" class="btn btn-primary chk-animation show_btn"><?php esc_html_e( 'OK, Next', 'javo-directory'); ?></a>
		<?php } ?>
    </div>
</div>

<div class="modal fade" id="exampleModal" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true">
	<div class="modal-dialog">
		<div class="modal-content">
			<div class="modal-header">
				<h5 class="modal-title" id="exampleModalLabel"><?php esc_html_e( 'Warning', 'javo-directory'); ?></h5>
				<button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
			</div>
			<div class="modal-body">
			<span><?php esc_html_e( 'Are you sure to process? It won`t be installed or imported propery.', 'javo-directory'); ?></span>
			</div>
			<div class="modal-footer">
				<button type="button" class="btn btn-secondary" data-bs-dismiss="modal"><?php esc_html_e( 'Close', 'javo-directory'); ?></button>
				<a href="<?php echo esc_url( $helper->get_next_step_link() ); ?>" class="btn btn-warning"><?php esc_html_e( 'Ignore & Next', 'javo-directory'); ?></a>
			</div>
		</div>
	</div>
</div>


