<?php
// Filter to allow external modification of page list if needed
$arrPages = apply_filters('jvbpd_filter_get_pages', jvbpd_tso()->getPages());
?>
<div class="tab-pane fade" id="v-pills-login" role="tabpanel" aria-labelledby="v-pills-login-tab" tabindex="0">
	<h2>
		<?php esc_html_e("Login & Register", 'javo-directory'); ?>
		<span class="description ms-3 text-capitalize">
			<?php echo sprintf(
				esc_html__('Set Page Default Templates. To create & manage templates, visit %s, %s on Javo Pagebuilder', 'javo-directory'),
				'<a href="edit.php?post_type=jvbpd-listing-elmt&template=custom_login" target="_blank">' . esc_html__('Login Templates', 'javo-directory') . '</a>',
				'<a href="edit.php?post_type=jvbpd-listing-elmt&template=custom_signup" target="_blank">' . esc_html__('Register Templates', 'javo-directory') . '</a>'
			); ?>
		</span>
	</h2>
	<!-- Action hook to allow additional content before the login settings -->
	<?php do_action('jvbpd_before_login_settings'); ?>

	<table class="form-table">
		<tr>
			<!-- Action hook to allow additional content before the login settings -->
			<?php do_action('jvbpd_before_login_settings_fields'); ?>
			<th>
				<h3 class="section-title ps-0 ms-0 mt-0">
					<?php esc_html_e("Login Settings", 'javo-directory'); ?>
				</h3>
				<span class="description">
					<?php esc_html_e("Rediection, Agreement on register link setting", 'javo-directory'); ?>
				</span>
			</th>
			<td>
				<div class="field-item form-floating mb-4">
					<!-- Filter to customize login redirect options for plugins -->
					<?php
					$login_redirect_options = apply_filters('jvbpd_login_redirect_options', array(
						'profile' => esc_html__('Dashboard Page (Default)', 'javo-directory'),
						'home' => esc_html__('Home Page', 'javo-directory'),
						'current' => esc_html__('Current Page', 'javo-directory'),
						'admin' => esc_html__('WordPress Profile Page', 'javo-directory'),
						'custom_page' => esc_html__('Custom Page', 'javo-directory')
					));
					?>

					<select class="selectpicker show-tick form-select" id="login_redirect" name="jvbpd_ts[login_redirect]" data-show-field='{"custom_page":["[data-login-redirect-custom-page]"]}'>
						<?php
						foreach ($login_redirect_options as $key => $text) {
							printf(
								'<option value="%1$s" %2$s>%3$s</option>',
								$key,
								selected(jvbpd_tso()->get('login_redirect', 'profile') == $key, true, false),
								$text
							);
						} ?>
					</select>
					<label for="login_redirect">
						<?php esc_html_e("Redirect to", 'javo-directory'); ?> :
					</label>
					<span class="field-help-text">
						<a class="helper-popover" data-bs-toggle="popover" tabindex="0" data-bs-trigger="focus"
							data-bs-title="<?php esc_html_e('Help & Tip', 'javo-directory'); ?>"
							data-bs-content="<?php esc_html_e('It should be a singular name. Not "Listings", "Places" or "Events"', 'javo-directory'); ?>">
							<i class="feather feather-help-circle"></i>
						</a>
					</span>
				</div>

				<!-- Filter to allow modification of custom pages list -->
				<div class="field-item form-floating mb-4" data-login-redirect-custom-page>
					<?php
					$custom_pages = apply_filters('jvbpd_custom_pages_list', get_pages());
					?>
					<select class="selectpicker show-tick form-select" id="login_redirect_custom_page" name="jvbpd_ts[login_redirect_custom_page]">
						<?php
						foreach ($custom_pages as $page) {
							printf(
								'<option value="%1$s" %2$s>%3$s</option>',
								$page->ID,
								selected(jvbpd_tso()->get('login_redirect_custom_page', '') == $page->ID, true, false),
								$page->post_title
							);
						} ?>
					</select>
					<label for="login_redirect_custom_page">
						<?php esc_html_e("Login Redirect Custom Page", 'javo-directory'); ?> :
					</label>
				</div>

				<!-- Filter to allow user agreement page list modification -->
				<div class="field-item form-floating mb-4">
					<?php
					$user_agreement_pages = apply_filters('jvbpd_user_agreement_pages', get_posts("post_type=page&post_status=publish&posts_per_page=-1&suppress_filters=0"));
					?>
					<select class="selectpicker show-tick form-select" data-live-search="true" data-size="10" id="user_agreement" name="jvbpd_ts[agree_register]">
						<option value="">
							<?php esc_html_e("Disable", 'javo-directory'); ?>
						</option>
						<?php
						if ($user_agreement_pages) {
							printf("<optgroup label=\"%s\">", esc_html__("Select a page for user agreement", 'javo-directory'));
							foreach ($user_agreement_pages as $post) {
								printf(
									"<option value=\"{$post->ID}\" %s>{$post->post_title}</option>",
									selected($post->ID == jvbpd_tso()->get('agree_register', ''), true, false)
								);
							}
							echo "</optgroup>";
						} ?>
					</select>
					<label for="user_agreement">
						<?php esc_html_e("User Agreement", 'javo-directory'); ?> :
					</label>
					<span class="field-help-text">
						<a class="helper-popover" data-bs-toggle="popover" tabindex="0" data-bs-trigger="focus"
							data-bs-title="<?php esc_html_e('Help & Tip', 'javo-directory'); ?>"
							data-bs-content="<?php esc_html_e('It should be a singular name. Not "Listings", "Places" or "Events"', 'javo-directory'); ?>">
							<i class="feather feather-help-circle"></i>
						</a>
					</span>
				</div>
			</td>
		</tr>
		<tr>
			<th>
				<h3 class="section-title ps-0 ms-0 mt-0">
					<?php esc_html_e("Signup Settings", 'javo-directory'); ?>
				</h3>
				<span class="description">
					<?php esc_html_e("Rediection, Agreement on register link setting", 'javo-directory'); ?>
				</span>
			</th>
			<td>
				<div class="field-item form-floating mb-4">
					<select class="selectpicker show-tick form-select" id="login_redirect" name="jvbpd_ts[signup_redirect]"
						data-show-field='{"custom_page":["[data-signup-redirect-custom-page]"]}'>
						<?php
						foreach (array('profile' => esc_html__('Dashboard Page (Default)', 'javo-directory'), 'home' => esc_html__('Home Page', 'javo-directory'), 'current' => esc_html__('Current Page', 'javo-directory'), 'admin' => esc_html__('WordPress Profile Page', 'javo-directory'), 'custom_page' => esc_html__('Custom Page', 'javo-directory')) as $key => $text) {
							printf(
								'<option value="%1$s" %2$s>%3$s</option>',
								$key,
								selected(jvbpd_tso()->get('signup_redirect', 'profile') == $key, true, false),
								$text
							);
						} ?>
					</select>
					<label for="login_redirect">
						<?php esc_html_e("Redirect to", 'javo-directory'); ?> :
					</label>
					<span class="field-help-text">
						<a class="helper-popover" data-bs-toggle="popover" tabindex="0" data-bs-trigger="focus"
							data-bs-title="<?php esc_html_e('Help & Tip', 'javo-directory'); ?>"
							data-bs-content="<?php esc_html_e('It should be a singular name. Not "Listings", "Places" or "Events"', 'javo-directory'); ?>">
							<i class="feather feather-help-circle"></i>
						</a>
					</span>
				</div>

				<div class="field-item form-floating mb-4" data-signup-redirect-custom-page>
					<select class="selectpicker show-tick form-select" id="login_redirect_custom_page"
						name="jvbpd_ts[signup_redirect_custom_page]">
						<?php
						foreach (get_pages() as $page) {
							printf(
								'<option value="%1$s" %2$s>%3$s</option>',
								$page->ID,
								selected(jvbpd_tso()->get('signup_redirect_custom_page', '') == $page->ID, true, false),
								$page->post_title
							);
						} ?>
					</select>
					<label for="login_redirect_custom_page">
						<?php esc_html_e("Signup Redirect Custom Page", 'javo-directory'); ?> :
					</label>
				</div>

			</td>
		</tr>
		<tr>
			<th>
				<h3 class="section-title ps-0 ms-0 mt-0">
					<?php esc_html_e("Modal Templates", 'javo-directory'); ?>
				</h3>
				<span class="description">
					<?php esc_html_e("Login, Sign-up Modal Template Setting", 'javo-directory'); ?>
				</span>
			</th>
			<td>
				<?php foreach (array('login_template' => array('label' => esc_html__("Login Modal Template", 'javo-directory'), 'options' => jvbpdCore()->admin->getElementorLoginID(),), 'sign_template' => array('label' => esc_html__("Sign-up Modal Template", 'javo-directory'), 'options' => jvbpdCore()->admin->getElementorSignupID(),),) as $metaKey => $meta) {
					$templateOptions = array('<option value="">' . esc_html__("Select one", 'javo-directory') . '</option>');
					foreach ($meta['options'] as $template_id) {
						if (!\WP_Post::get_instance($template_id)) {
							continue;
						}
						$templateOptions[] = sprintf(
							'<option value="%1$s"%3$s>%2$s</option>',
							$template_id,
							get_the_title($template_id),
							selected($template_id == jvbpd_tso()->get($metaKey, ''), true, false)
						);
					}
					printf(
						'<div class="field-item form-floating mb-4"><select class="selectpicker show-tick form-select" data-live-search="true" data-size="10" id="%2$s" name="jvbpd_ts[%2$s]">%3$s</select><label for="%2$s">%1$s</label></div>',
						$meta['label'],
						$metaKey,
						join(false, $templateOptions)
					);
				} ?>
			</td>
		</tr>
		<tr>
			<th>
				<h3 class="section-title ps-0 ms-0 mt-0">
					<?php esc_html_e("Custom Login Page", 'javo-directory'); ?>
				</h3>
				<span class="description">
					<?php esc_html_e("Use a custom login, sign-up page(Full Page) instead of WordPress Login", 'javo-directory'); ?>
				</span>
			</th>
			<td>
				<div class="field-item form-floating mb-4">
					<select class="selectpicker show-tick form-select" data-live-search="true" data-size="10"
						id="selectLoginPage" name="jvbpd_ts[login_page]">
						<option value="none">
							<?php esc_html_e("Wordpress Login", 'javo-directory'); ?>
						</option>
						<?php
						foreach ($arrPages as $objPage) {
							printf(
								'<option value="%1$s"%3$s>%2$s</option>',
								$objPage->ID,
								$objPage->post_title,
								selected(jvbpd_tso()->get('login_page') == $objPage->ID, true, false)
							);
						} ?>
					</select>
					<label for="selectLoginPage">
						<?php esc_html_e("Login Page", 'javo-directory'); ?>
					</label>
					<span class="field-help-text">
						<a class="helper-popover" data-bs-toggle="popover" tabindex="0" data-bs-trigger="focus"
							data-bs-title="<?php esc_html_e('Help & Tip', 'javo-directory'); ?>"
							data-bs-content="<?php esc_html_e('To create a shortcode, please go to javo builder and create one to get a shortcode', 'javo-directory'); ?>">
							<i class="feather feather-help-circle"></i>
						</a>
					</span>
				</div>

				<div class="field-item form-floating mb-4">
					<select class="selectpicker show-tick form-select" data-live-search="true" data-size="10"
						id="selectRegisterPage" name="jvbpd_ts[register_page]">
						<option value="none">
							<?php esc_html_e("Wordpress Register", 'javo-directory'); ?>
						</option>
						<?php
						foreach ($arrPages as $objPage) {
							printf(
								'<option value="%1$s"%3$s>%2$s</option>',
								$objPage->ID,
								$objPage->post_title,
								selected(jvbpd_tso()->get('register_page') == $objPage->ID, true, false)
							);
						} ?>
					</select>
					<label for="selectRegisterPage">
						<?php esc_html_e("Register Page", 'javo-directory'); ?>
					</label>
					<span class="field-help-text">
						<a class="helper-popover" data-bs-toggle="popover" tabindex="0" data-bs-trigger="focus"
							data-bs-title="<?php esc_html_e('Help & Tip', 'javo-directory'); ?>"
							data-bs-content="<?php esc_html_e('To create a shortcode, please go to javo builder and create one to get a shortcode', 'javo-directory'); ?>">
							<i class="feather feather-help-circle"></i>
						</a>
					</span>
				</div>
			</td>
		</tr>
		<tr>
			<th>
				<h3 class="section-title ps-0 ms-0 mt-0">
					<?php esc_html_e("Restricted Site Access", 'javo-directory'); ?>
				</h3>
				<span class='description'>
					<?php esc_html_e("Lock whole site without login", 'javo-directory'); ?>
				</span>
			</th>
			<td>
				<?php if (function_exists('jvbpdCore') && defined('ELEMENTOR_VERSION')): ?>
					<div class="field-item form-floating mb-4">
						<select class="selectpicker show-tick form-select" name="jvbpd_ts[login_required]"
							data-show-field='{"enable":["[data-login-req]"]}' id="site_login_required"
							aria-label="<?php esc_html_e('Select a page', 'javo-directory'); ?>">
							<?php
							foreach (array('disabled' => esc_html__('Disabled', 'javo-directory'), 'enable' => esc_html__('Enable', 'javo-directory'),) as $strOptionValue => $strOptionLabel) {
								printf(
									'<option value="%1$s"%3$s>%2$s</option>',
									$strOptionValue,
									$strOptionLabel,
									selected($strOptionValue == jvbpd_tso()->get('login_required', 'disabled'), true, false)
								);
							} ?>
						</select>
						<label for="site_login_required">
							<?php esc_html_e('Login Required (Whole Site)', 'javo-directory'); ?>
						</label>
						<span class="field-help-text">
							<a class="helper-popover" data-bs-toggle="popover" tabindex="0" data-bs-trigger="focus"
								data-bs-title="<?php esc_html_e('Help & Tip', 'javo-directory'); ?>"
								data-bs-content="<?php esc_html_e('If on, all site won`t be able to access without loing. It will be redirected a login page.', 'javo-directory'); ?>">
								<i class="feather feather-help-circle"></i>
							</a>
						</span>
					</div>

					<?php
					$login_required_opt['disabled'] = esc_html__("Select Page", 'javo-directory');
					foreach (get_posts("post_type=page&post_status=publish&posts_per_page=-1&suppress_filters=0") as $page) {
						$login_required_opt[$page->ID] = $page->post_title;
					} ?>
					<div class="field-item form-floating mb-4" data-login-req>
						<select class="selectpicker show-tick form-select" name="jvbpd_ts[login_required_front_page]"
							data-live-search="true" data-size="10" id="front_page_not_loggedin"
							aria-label="<?php esc_html_e('Select a page', 'javo-directory'); ?>" data-bs-toggle="tooltip"
							data-bs-placement="top"
							title="<?php esc_html_e('This field will be displayed only selected packages', 'javo-directory'); ?>">
							<?php
							foreach ($login_required_opt as $strOptionValue => $strOptionLabel) {
								printf(
									'<option value="%1$s"%3$s>%2$s</option>',
									$strOptionValue,
									$strOptionLabel,
									selected($strOptionValue == jvbpd_tso()->get('login_required_front_page', 'disabled'), true, false)
								);
							} ?>
						</select>
						<label for="front_page_not_loggedin">
							<?php esc_html_e('Front page when not logged in', 'javo-directory'); ?>
						</label>
						<span class="field-help-text">
							<a class="helper-popover" data-bs-toggle="popover" data-bs-html="true" tabindex="0"
								data-bs-trigger="focus" data-bs-title="<?php esc_html_e('Help & Tip', 'javo-directory'); ?>"
								data-bs-content="<?php esc_html_e('When site required to login, it will be redirected to this page. This page will be the front (Home) page. <br><br>To create a page, please move to <a href="edit.php?post_type=page" target="_blank">pages</a> and add links to login and sign-up page. And then select the pages below Login, Sign-up selections', 'javo-directory'); ?>">
								<i class="feather feather-help-circle"></i>
							</a>
						</span>
					</div>
				<?php endif; ?>
			</td>
		</tr>
		<tr>
			<th>
				<h3 class="section-title ps-0 ms-0 mt-0">
					<?php esc_html_e("Twilio Settings", 'javo-directory'); ?>
				</h3>
				<span class="description">
					<?php esc_html_e("Twilio Setting", 'javo-directory'); ?>
				</span>
			</th>
			<td>
				<div class="field-item form-floating field-floating-menu-content mt-3">
					<input type="text" class="form-control" id="floating-shortcode" name="jvbpd_ts[twilio_sid]"
						placeholder="<?php esc_html_e('Twilio Secret ID', 'javo-directory'); ?>"
						value="<?php echo esc_attr(jvbpd_tso()->get('twilio_sid')); ?>">
					<label for="floating-shortcode">
						<?php esc_html_e('Twilio Secret ID', 'javo-directory'); ?>
					</label>
				</div>
				<div class="field-item form-floating field-floating-menu-content mt-3">
					<input type="text" class="form-control" id="floating-shortcode" name="jvbpd_ts[twilio_token]"
						placeholder="<?php esc_html_e('Twilio Token', 'javo-directory'); ?>"
						value="<?php echo esc_attr(jvbpd_tso()->get('twilio_token')); ?>">
					<label for="floating-shortcode">
						<?php esc_html_e('Twilio Token', 'javo-directory'); ?>
					</label>
				</div>
				<div class="field-item form-floating field-floating-menu-content mt-3">
					<input type="text" class="form-control" id="floating-shortcode" name="jvbpd_ts[twilio_from]"
						placeholder="<?php esc_html_e('From Number', 'javo-directory'); ?>"
						value="<?php echo esc_attr(jvbpd_tso()->get('twilio_from')); ?>">
					<label for="floating-shortcode">
						<?php esc_html_e('From Number', 'javo-directory'); ?>
					</label>
				</div>
				<div class="field-item form-check form-switch d-flex align-items-center gap-2 mt-3">
					<?php
					foreach (array('disable' => esc_html__("Disabled", 'jvfrmtd'), 'enable' => esc_html__("Enable", 'jvfrmtd'),) as $strSwitchKey => $strSwitchLabel) {
						printf(
							'<input type="%1$s" id="jvbpd-twilio-enable-submit-listing-%1$s" name="jvbpd_ts[twilio_enable_submit_listing]" value="%2$s" class="field-item form-check-input"%3$s>',
							('disable' == $strSwitchKey ? 'hidden' : 'checkbox'),
							$strSwitchKey,
							checked($strSwitchKey == jvbpd_tso()->get('twilio_enable_submit_listing', 'disable'), true, false),
						);
					} ?>
					<label class="field-item form-check-label" for="jvbpd-twilio-enable-submit-listing-checkbox">
						<?php esc_html_e("Use Twilio authentication in the Submit Listing( Javo Dashboard )", 'jvfrmtd'); ?>
					</label>
					<span class="description">
						<?php esc_html_e("This opion is for only dashboard. You can enable/disable it for each applicable widget (Login, Signup, Submit form).", 'javo-directory'); ?>
					</span>
				</div>
				<div class="field-item form-check form-switch d-flex align-items-center gap-2 mt-3">
					<?php
					foreach (array('disable' => esc_html__("Disabled", 'jvfrmtd'), 'enable' => esc_html__("Enable", 'jvfrmtd'),) as $strSwitchKey => $strSwitchLabel) {
						printf(
							'<input type="%1$s" id="jvbpd-twilio-enable-dashboard-%1$s" name="jvbpd_ts[twilio_enable_dashboard]" value="%2$s" class="field-item form-check-input"%3$s>',
							('disable' == $strSwitchKey ? 'hidden' : 'checkbox'),
							$strSwitchKey,
							checked($strSwitchKey == jvbpd_tso()->get('twilio_enable_dashboard', 'disable'), true, false),
						);
					} ?>
					<label class="field-item form-check-label" for="jvbpd-twilio-enable-dashboard-checkbox">
						<?php esc_html_e("Use Twilio authentication in the Javo Dashboard All Pages", 'jvfrmtd'); ?>
					</label>
				</div>
			</td>
		</tr>
	</table>
</div>